=====================
WeatherAlerts README
=====================

.. image:: https://badges.gitter.im/zebpalmer/WeatherAlerts.svg
   :alt: Join the chat at https://gitter.im/zebpalmer/WeatherAlerts
   :target: https://gitter.im/zebpalmer/WeatherAlerts?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge





2017 PROJECT STATUS
===================
This package is old and in need of TLC but, surprisingly, I continue to get questions about it. So,
I'm finally going to revamp it. I actually started that last year, but life (toddler) didn't seem to let me finish it.
If you're interested in the future of this project, want to help, or have questions --
join the gitter.im chat via the link above.


Compatability Update
---------------------
If you are using this package currently, you'll want to pin the version you have in your project. Future versions will
not work with the 0.4.x API (sorry). I'm also dropping support for python 2.6, or rather, I'm no longer testing for
python versions prior to 2.7 (specifically 2.7.11).

Supported python versions: 2.7, 3.5, 3.6


Documentation
==============
Please see http://weatheralerts.readthedocs.org for documentation

This project lives at `github.com/zebpalmer/WeatherAlerts <http://github.com/zebpalmer/WeatherAlerts>`_


License
---------
MIT


Install
---------
You can download and install/upgrade via PIP by runing:  ``pip install -U weatheralerts``


